# coding: utf-8

"""
DEX AI API

API for DEX AI

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set, Union

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing_extensions import Self


class SignalOverviewStats(BaseModel):
    """
    Model for signal statistics response
    """  # noqa: E501

    timestamp: StrictInt = Field(
        description="The unix timestamp of the stats calculation"
    )
    total: StrictInt = Field(description="Total number of tokens analyzed")
    win_rate: Union[StrictFloat, StrictInt] = Field(
        description="Overall win rate as a percentage"
    )
    avg_performance: Union[StrictFloat, StrictInt] = Field(
        description="Average performance as a percentage"
    )
    median_performance: Union[StrictFloat, StrictInt] = Field(
        description="Median performance as a percentage"
    )
    best_risk_category: Optional[StrictStr] = None
    best_month: Optional[StrictStr] = None
    best_holding_period: Optional[StrictStr] = None
    best_launch_hour: Optional[StrictInt] = None
    best_launch_day: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = [
        "timestamp",
        "total",
        "win_rate",
        "avg_performance",
        "median_performance",
        "best_risk_category",
        "best_month",
        "best_holding_period",
        "best_launch_hour",
        "best_launch_day",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SignalOverviewStats from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if best_risk_category (nullable) is None
        # and model_fields_set contains the field
        if (
            self.best_risk_category is None
            and "best_risk_category" in self.model_fields_set
        ):
            _dict["best_risk_category"] = None

        # set to None if best_month (nullable) is None
        # and model_fields_set contains the field
        if self.best_month is None and "best_month" in self.model_fields_set:
            _dict["best_month"] = None

        # set to None if best_holding_period (nullable) is None
        # and model_fields_set contains the field
        if (
            self.best_holding_period is None
            and "best_holding_period" in self.model_fields_set
        ):
            _dict["best_holding_period"] = None

        # set to None if best_launch_hour (nullable) is None
        # and model_fields_set contains the field
        if (
            self.best_launch_hour is None
            and "best_launch_hour" in self.model_fields_set
        ):
            _dict["best_launch_hour"] = None

        # set to None if best_launch_day (nullable) is None
        # and model_fields_set contains the field
        if self.best_launch_day is None and "best_launch_day" in self.model_fields_set:
            _dict["best_launch_day"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SignalOverviewStats from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "timestamp": obj.get("timestamp"),
                "total": obj.get("total"),
                "win_rate": obj.get("win_rate"),
                "avg_performance": obj.get("avg_performance"),
                "median_performance": obj.get("median_performance"),
                "best_risk_category": obj.get("best_risk_category"),
                "best_month": obj.get("best_month"),
                "best_holding_period": obj.get("best_holding_period"),
                "best_launch_hour": obj.get("best_launch_hour"),
                "best_launch_day": obj.get("best_launch_day"),
            }
        )
        return _obj
