# coding: utf-8

# flake8: noqa

"""
Hive AI API

API for Hive AI model training and evaluation

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "DataApi",
    "ModelsApi",
    "StatusApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ApiErrorIdentifier",
    "ApiErrorLevel",
    "ApiErrorType",
    "CoinInfo",
    "Coins",
    "DataDownloadResponse",
    "DataInfo",
    "DataOptions",
    "DataVersion",
    "DataVersionInfo",
    "DownloadLinks",
    "Evaluation",
    "EvaluationResponse",
    "ExceptionDetail",
    "FeatureSize",
    "ModelCreate",
    "ModelRead",
    "ModelStatus",
    "ModelUpdate",
    "Target",
    "TargetInfo",
    "TargetType",
]

# import apis into sdk package
from crypticorn.hive.client.api.data_api import DataApi as DataApi
from crypticorn.hive.client.api.models_api import ModelsApi as ModelsApi
from crypticorn.hive.client.api.status_api import StatusApi as StatusApi
from crypticorn.hive.client.api_client import ApiClient as ApiClient

# import ApiClient
from crypticorn.hive.client.api_response import ApiResponse as ApiResponse
from crypticorn.hive.client.configuration import Configuration as Configuration
from crypticorn.hive.client.exceptions import ApiAttributeError as ApiAttributeError
from crypticorn.hive.client.exceptions import ApiException as ApiException
from crypticorn.hive.client.exceptions import ApiKeyError as ApiKeyError
from crypticorn.hive.client.exceptions import ApiTypeError as ApiTypeError
from crypticorn.hive.client.exceptions import ApiValueError as ApiValueError
from crypticorn.hive.client.exceptions import OpenApiException as OpenApiException

# import models into sdk package
from crypticorn.hive.client.models.api_error_identifier import (
    ApiErrorIdentifier as ApiErrorIdentifier,
)
from crypticorn.hive.client.models.api_error_level import ApiErrorLevel as ApiErrorLevel
from crypticorn.hive.client.models.api_error_type import ApiErrorType as ApiErrorType
from crypticorn.hive.client.models.coin_info import CoinInfo as CoinInfo
from crypticorn.hive.client.models.coins import Coins as Coins
from crypticorn.hive.client.models.data_download_response import (
    DataDownloadResponse as DataDownloadResponse,
)
from crypticorn.hive.client.models.data_info import DataInfo as DataInfo
from crypticorn.hive.client.models.data_options import DataOptions as DataOptions
from crypticorn.hive.client.models.data_version import DataVersion as DataVersion
from crypticorn.hive.client.models.data_version_info import (
    DataVersionInfo as DataVersionInfo,
)
from crypticorn.hive.client.models.download_links import DownloadLinks as DownloadLinks
from crypticorn.hive.client.models.evaluation import Evaluation as Evaluation
from crypticorn.hive.client.models.evaluation_response import (
    EvaluationResponse as EvaluationResponse,
)
from crypticorn.hive.client.models.exception_detail import (
    ExceptionDetail as ExceptionDetail,
)
from crypticorn.hive.client.models.feature_size import FeatureSize as FeatureSize
from crypticorn.hive.client.models.model_create import ModelCreate as ModelCreate
from crypticorn.hive.client.models.model_read import ModelRead as ModelRead
from crypticorn.hive.client.models.model_status import ModelStatus as ModelStatus
from crypticorn.hive.client.models.model_update import ModelUpdate as ModelUpdate
from crypticorn.hive.client.models.target import Target as Target
from crypticorn.hive.client.models.target_info import TargetInfo as TargetInfo
from crypticorn.hive.client.models.target_type import TargetType as TargetType
